Note that the following config files can be automatically generated during deployement with the set of utilities provided in the `utils` directory in this repository:

* conda.config
* docker.config
* multiconda.config
* path.config
* singularity.config
